@@ -648,9 +648,14 @@ class S3(Database):
         except Exception as e:
             raise ValueError('Error generating cloud credentials') from e
 
+    def really_close(self):
+        super().really_close()
+        if self.__sts_client is not None:
+            self.__sts_client.close()
+
     def close(self):
         super().close()
-        if self.__sts_client is not None:
+        if self.__sts_client is not None and not self.managed:
             self.__sts_client.close()
 
     async def elevate_privileges(self, request: web.Request, credentials: AWSCredentials,
@@ -888,7 +893,7 @@ class S3Manager(MicroserviceDatabaseManager):
     """
 
     def get_database(self) -> S3:
-        return S3(self.config)
+        return S3(self.config, managed=True)
 
     @classmethod
     def database_types(self) -> list[str]:
@@ -898,7 +903,7 @@ class S3Manager(MicroserviceDatabaseManager):
 class S3WithMongoManager(S3Manager):
 
     def get_database(self) -> S3:
-        return S3WithMongo(self.config)
+        return S3WithMongo(self.config, managed=True)
 
 
 class S3ClientContext(DatabaseContextManager[S3Client, AWSCredentials]):  # Go into db package?
