@@ -61,6 +61,7 @@ class Mongo(Database):
                  username: Optional[str] = None,
                  password: Optional[str] = None,
                  database_name: Optional[str] = None,
+                 managed = False,
                  **kwargs) -> None:
         """
         Performs initialization.
@@ -78,9 +79,8 @@ class Mongo(Database):
         :param password: an optional password that will override any password in the connection string.
         :param database_name: an optional database name that will override any database name in a provided config file.
         """
-        super().__init__(config, **kwargs)
+        super().__init__(config, managed=managed, **kwargs)
         logger = logging.getLogger(__name__)
-
         default_connection_string = 'mongodb://heauser:heauser@localhost:27017/hea'
 
         config_section = Mongo.get_config_section()
@@ -124,7 +124,7 @@ class Mongo(Database):
                 conn_url = conn_url.with_password(password)
             logger.debug('\tUsing connection string %s',
                          str(conn_url.with_password('xxxxxxxx')) if conn_url.password is None else str(conn_url))
-            self.__client = motor_asyncio.AsyncIOMotorClient(str(conn_url))
+            self.__client = motor_asyncio.AsyncIOMotorClient(str(conn_url), maxIdleTimeMS=30 * 1000)
             if database_name is not None:
                 self.__connection_pool = self.__client.get_database(name=database_name)
             else:
@@ -702,10 +702,18 @@ class Mongo(Database):
         """
         await self.__connection_pool.command('ping')
 
-    def close(self):
-        super().close()
+    def really_close(self):
+        """Closes the MongoDB client connection, and it also calls the superclass' really_close method."""
+        super().really_close()
         self.__client.close()
 
+    def close(self):
+        """Skips closing the MongoDB client connection if this is a managed Mongo instance. It also closes the
+        superclass' close method."""
+        super().close()
+        if not self.managed:
+            self.__client.close()
+
     def __copy_to_dict(self, result: Mapping[str, Any]) -> root.DesktopObjectDict:
         return dict({'id' if k == '_id' else k: str(v) if k == '_id' else v for k, v in result.items() if k != 'id'})
 
@@ -784,7 +792,7 @@ class MongoManager(MicroserviceDatabaseManager):
         super().__init__(config)
 
     def get_database(self) -> Mongo:
-        return Mongo(config=self.config)
+        return Mongo(config=self.config, managed=True)
 
     @classmethod
     def get_environment_updates(cls) -> dict[str, str]:
@@ -813,19 +821,6 @@ class MongoContext(DatabaseContextManager[Mongo, Credentials]): # Go into db pac
     async def connection(self) -> Mongo:
         return await _get_mongo(self.request, self.volume_id)
 
-    async def __aexit__(self, exc_type, exc_value, traceback) -> None:
-        """
-        No-op. The python motor driver abstracts away connections, so no need to close anything. Because we use the
-        Mongo object as the connection object, and its close() method closes the client, we override __aexit__ to do
-        nothing and return None.
-
-        :param exc_type: the type of exception thrown in the context body, if any.
-        :param exc_value: the exception itself, if any.
-        :param traceback: the traceback, if any.
-
-        """
-        pass
-
 
 async def _get_mongo(request: web.Request, volume_id: Optional[str]) -> Mongo:
     """
@@ -835,7 +830,8 @@ async def _get_mongo(request: web.Request, volume_id: Optional[str]) -> Mongo:
     :param volume_id: the id string of a volume.
     :return: a Mongo client for the file system specified by the volume's file_system_name attribute. If no volume_id
     was provided, the return value will be the "default" Mongo client for the microservice found in the HEA_DB
-    application-level property.
+    application-level property. If the default Mongo client is used, its close method will do nothing since it's closed
+    on microservice shutdown.
     :raise ValueError: if there is no volume with the provided volume id, the volume's file system does not exist,
     or a necessary service is not registered.
     """
@@ -847,4 +843,4 @@ async def _get_mongo(request: web.Request, volume_id: Optional[str]) -> Mongo:
         else:
             return Mongo(None, connection_string=file_system.connection_string, username=credentials.account, password=credentials.password)
     else:
-        return request.app[HEA_DB]
+        return cast(Mongo, request.app[HEA_DB])
