@@ -1,27 +1,29 @@
 import asyncio
 import configparser
 import logging
-from abc import ABC
-from typing import Optional, TypeVar, List, Any, AsyncGenerator
+from typing import Optional, TypeVar, Any, AsyncGenerator
 
 import opensearchpy
 from aiohttp import web
-from aiohttp.web_request import Request
 from cachetools import TTLCache
 from heaobject.error import DeserializeException
 from heaobject.keychain import Credentials
 from heaobject.root import HEAObjectDict, json_dumps
 from heaobject.volume import OpenSearchFileSystem, FileSystem
-from opensearchpy import AsyncOpenSearch, RequestError, OpenSearchException
+from opensearchpy import AsyncOpenSearch, RequestError
 from heaserver.service.aiohttp import extract_sub
 from heaserver.service.appproperty import HEA_DB
-from heaserver.service.db.aws import S3, S3Manager
+from heaserver.service.db.aws import S3
 from heaserver.service.db.database import Database, DatabaseContextManager, MicroserviceDatabaseManager, \
     get_file_system_and_credentials_from_volume, get_credentials_from_volume
 from configparser import ConfigParser
-from heaobject.folder import Item, AWSS3Item
+from heaobject.folder import Item
 
-from heaserver.service.db.mongo import Mongo, MongoManager
+from heaserver.service.db.mongo import Mongo
+import threading
+import time
+
+from heaserver.service.testcase.util import run_coroutine_in_new_event_loop
 
 CONFIG_SECTION="Opensearch"
 
@@ -381,9 +383,12 @@ class OpenSearch(Database):
             logging.exception(f"Failed to delete item {item_id}: {e}")
             raise e
 
-    async def close(self):
+    def really_close(self):
+        logger = logging.getLogger(__name__)
         if self.__client:
-            await self.__client.close()
+            logger.debug("Closing OpenSearch client...")
+            run_coroutine_in_new_event_loop(self.__client.close())
+            logger.debug("OpenSearch client closed.")
 
 
 class S3WithOpenSearch(S3, OpenSearch):
@@ -408,7 +413,7 @@ class OpenSearchManager(MicroserviceDatabaseManager):
         """
         Initializes and returns an instance of OpenSearchClient with the provided configuration.
         """
-        return OpenSearch(config=self.config)
+        return OpenSearch(config=self.config, managed=True)
 
     @classmethod
     def database_types(self) -> list[str]:
@@ -421,8 +426,7 @@ class S3WithOpenSearchManager(OpenSearchManager):
         """
         Initializes and returns an instance of OpenSearchClient with the provided configuration.
         """
-        client = S3WithOpenSearch(
-            config =self.config )
+        client = S3WithOpenSearch(config =self.config, managed=True)
         return client
 
 
@@ -432,8 +436,7 @@ class MongoWithOpenSearchManager(OpenSearchManager):
         """
         Initializes and returns an instance of OpenSearchClient with the provided configuration.
         """
-        client = MongoWithOpenSearch(
-            config =self.config)
+        client = MongoWithOpenSearch(config=self.config, managed=True)
         return client
 
 class S3MongoOpenSearchMananger(OpenSearchManager):
@@ -442,8 +445,7 @@ class S3MongoOpenSearchMananger(OpenSearchManager):
         """
         Initializes and returns an instance of OpenSearchClient with the provided configuration.
         """
-        client = S3AndMongoWithOpenSearch(
-            config =self.config)
+        client = S3AndMongoWithOpenSearch(config =self.config, managed=True)
         return client
 
 
