@@ -234,7 +234,7 @@ def get_application(package_name: str | None = None,
     if db:
         async def _db(app: web.Application) -> AsyncIterator[None]:
             if db:
-                with db.database() as database:
+                async with db.database() as database:
                     app[appproperty.HEA_DB] = database
                     yield
             else:
