@@ -8,7 +8,7 @@ class S3WithDockerMongoManager(S3Manager, DockerMongoManager):
     microservices need to be running."""
 
     def get_database(self) -> S3WithMongo:
-        return S3WithMongo(config=self.config)
+        return S3WithMongo(config=self.config, managed=True)
 
     @classmethod
     def database_types(self) -> list[str]:
@@ -25,7 +25,7 @@ class MockS3WithMockDockerMongoManager(MockS3Manager, MockDockerMongoManager):
     """
 
     def get_database(self) -> MockS3WithMongo:
-        return MockS3WithMongo(config=self.config)
+        return MockS3WithMongo(config=self.config, managed=True)
 
     @classmethod
     def database_types(self) -> list[str]:
