@@ -173,7 +173,7 @@ class MockDockerMongoManager(DockerMongoManager):
                 """
                 return PermissionContext(sub=request.headers.get(SUB, NONE_USER))
 
-        return MongoWithOverriddenIsCreator(config=self.config)
+        return MongoWithOverriddenIsCreator(config=self.config, managed=True)
 
 class DockerMongoManagerWithNoDatabaseManager(DockerMongoManager, NoDatabaseManager):
     def get_database(self) -> Mongo:
