@@ -475,7 +475,7 @@ class MockMongoManager(MongoManager):
         return result
 
     def start_database(self, context_manager: ExitStack) -> None:
-        self.__mongo = MockMongo()
+        self.__mongo = MockMongo(managed=True)
         super().start_database(context_manager)
 
     def insert_desktop_objects(self, desktop_objects: Optional[Mapping[CollectionKey, Sequence[DesktopObjectDict]]]):
